#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Parse an sql file for A7
from django.contrib.auth.models import User
from django.core.management.base import NoArgsCommand, CommandError
from django.conf import settings

from gestion.inscriptions.models import Inscription
from portailuser.models import Ecole
from gestion.inscriptions.logins import genere_login, NomVide, PrenomVide

import datetime
import csv
import os


class Command(NoArgsCommand):
    help = "Inscription A7 promo 2015"

    def handle_noargs(self, *args, **kwargs):
        main("annuaire_a7_2015.csv")  # promo 2015


def crea_inscr_obj(user):
    """Create an Inscription object with USER)"""
    print(user["nom"] + ":")

    # generate login
    try:
        login = genere_login(user["nom"], user["prenom"])
    except NomVide:
        print("Ce nom ne contient pas de caractères alphabétiques.")
    except PrenomVide:
        print("Ce prénom ne contient pas de caractères alphabétiques.")

    if not login:
        print("Impossible de générer un login unique !")

    # generate a passwd
    mdp = User.objects.make_random_password()

    inscription = Inscription()
    inscription.nom = user["nom"]
    inscription.prenom = user["prenom"]
    inscription.date_naissance = user["birthday"]  # DateField
    inscription.genre = user["sexe"]  # 1 : masc ; 2 : fem

    inscription.promo = user["promo"]
    inscription.ecole = Ecole.a7  # Ecole
    inscription.filiere = "ou=" + user["filiere"] + ",ou=filieres,o=a7,dc=etu-inpt,dc=fr"
    inscription.inscrit_ae = True  # bool

    inscription.surnom = user["pseudo"]
    inscription.email = user["email"]

    inscription.adresse = user["adresse_scolaire"]
    inscription.adr_parents = user["adresse_parents"]

    inscription.tel_mobile = user["tel_mobile"]  # PortailUser…
    # inscription.tel_perso = # PortailUser… -> optionnel et vide !

    # inscription.fiche_imp =

    inscription.login = login
    inscription.mdp = mdp

    # inscription.date_ajout = # DateTimeField

    inscription.etat = 0  # ? 0 : ok ; 1 : avert ; 2 : erreur
    # inscription.ident_cri =
    # inscription.mail_cri =

    inscription.save()

    print("ok (id : {inscription.id})")

    try:
        os.rename(
            settings.INSCRIPT_PHOTOS_DST + "/" + user["nb_photo"] + ".JPG",
            settings.INSCRIPT_PHOTOS_DST + "/" + str(inscription.id) + ".jpg",
        )
    except Exception as e:
        print("*" * 10)
        print("Erreur :" + str(e))
        print("*" * 10)


def requete(csv_file):
    """Transform datas in a good query"""
    query = dict(
        {
            "nom": "",
            "prenom": "",
            "pseudo": "",
            "email": "",
            "sexe": "",
            "promo": "",
            "filiere": "",
            "nb_photo": "",
            "birthday": "",
            "adresse_scolaire": "",
            "adresse_parents": "",
            "tel_mobile": "",
        }
    )
    query_keys = sorted(query.keys())

    with open(csv_file, "r") as f:
        freader = csv.reader(f, delimiter=";", quotechar='"')
        for j, ligne in enumerate(freader):
            if j != 0:
                # dans le dico
                eleve = query
                for i, data in enumerate(query_keys):
                    eleve[data] = ligne[i]

                # parsing
                eleve["nom"] = eleve["nom"].decode("utf8").title().strip().encode("utf8")
                eleve["prenom"] = eleve["prenom"].decode("utf8").title().strip().encode("utf8")
                eleve["pseudo"] = eleve["pseudo"].decode("utf8").strip().encode("utf8")
                eleve["email"] = eleve["email"].lower().strip()
                eleve["sexe"] = (eleve["sexe"].strip() == "F") + 1
                eleve["promo"] = int(eleve["promo"])
                eleve["filiere"] = eleve["filiere"].lower().strip()
                # birthday : year-month-day
                birth = eleve["birthday"].split("/")[::-1]
                eleve["birthday"] = datetime.date(int(birth[0]), int(birth[1]), int(birth[2]))
                eleve["adresse_scolaire"] = eleve["adresse_scolaire"].decode("utf8").strip().title().encode("utf8")
                eleve["adresse_parents"] = eleve["adresse_parents"].decode("utf8").strip().title().encode("utf8")
                eleve["tel_mobile"] = eleve["tel_mobile"].replace(" ", "")

                crea_inscr_obj(eleve)


def main(csv_file):
    """Main"""
    if os.path.isfile(csv_file):
        requete(csv_file)
    else:
        raise CommandError("Pas de données")


if __name__ == "__main__":
    main("annuaire_a7_2015.csv")  # promo 2015
